@@ -9,7 +9,7 @@ my $mw = new MainWindow(
   -background => 'white',
 );
 my $GraphDummies = $mw->Bars(
-  -title      => 'My chart title',
+  -title      => 'Tk::ForDummies::Graph::Bars - no spacingbar',
   -xlabel     => 'X Label',
   -ylabel     => 'Y Label',
   -background => 'snow',
@@ -24,18 +24,18 @@ my @data = (
   [ 1,     2,     52,    6,     3,     17.5,  1,     43,    10 ]
 );
 
-# Add a legend to the chart
+# Add a legend to the graph
 my @Legends = ( 'legend 1', 'legend 2', 'legend 3' );
 $GraphDummies->set_legend(
-  -title       => "Title legend",
+  -title       => 'Title legend',
   -data        => \@Legends,
-  -titlecolors => "blue",
+  -titlecolors => 'blue',
 );
 
 # Add help identification
 $GraphDummies->set_balloon();
 
-# Create the chart
+# Create the graph
 $GraphDummies->plot( \@data );
 
 MainLoop();
